{% extends "admin/base_site.html" %}
{% load i18n humanize palette %}

{% block content %}
<div class="card p-3 shadow mx-auto text-center" style="max-width: 400px;">
  <h1> <i class="bi bi-shield-lock"></i> </h1>
  <h5> {% translate 'Your password was changed!' %} </h5>
  <p> {% translate 'Please logout and log in back again to verify.' %} </p>

  <a href="{% url 'admin:logout' %}" class="btn btn-sm btn-warning my-3"> {% translate 'Log out' %} </a>
</div>
{% endblock %}
