{% load i18n static palette %}
<!DOCTYPE html>
{% get_current_language as LANGUAGE_CODE %}{% get_current_language_bidi as LANGUAGE_BIDI %}
<html lang="{{ LANGUAGE_CODE|default:"en-us" }}" dir="{{ LANGUAGE_BIDI|yesno:'rtl,ltr,auto' }}">
<head>
  <title>{% block title %}Admin{% endblock %}</title>
  {% block stylesheet %}
    <link rel="stylesheet" href="{% static 'palette/css/base.css' %}">
  {% endblock %}
  
  <link href="{% static 'css/bootstrap.min.css' %}" rel="stylesheet">
  <link href="{% static 'css/bootstrap-icons.css'%}" rel="stylesheet">
  <link href="{% static 'css/select2.min.css' %}" rel="stylesheet">
  <link href="{% static 'css/select2-bootstrap-5-theme.min.css' %}" rel="stylesheet">

  {% block dark-mode-vars %}{% endblock %}
  {% block extrastyle %}{% endblock %}
  {% block extrahead %}{% endblock %}
  {% block responsive %}
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
  {% endblock %}
  {% block blockbots %}<meta name="robots" content="NONE,NOARCHIVE">{% endblock %}
  <style>
    span.select2-selection{
      padding-top: 5px !important;
      min-height: 40px !important;
    }

    .select2-container--default .select2-selection--single .select2-selection__arrow{
      top: 15%;
    }

  </style>
</head>

<body>
  {% block body %}
  
  {% endblock body %}
<script src="{% static 'js/bootstrap.bundle.min.js'%}"></script>
<script src="{% static 'js/jquery.slim.min.js'%}"></script>
<script src="{% static 'js/select2.min.js'%}"></script>
<script src="{% static 'js/htmx.min.js'%}"></script>
<script type="text/javascript">
  $(document).ready(function(){
    $('.select2').select2();
  })
</script>

{% block extra_scripts %}

{% endblock extra_scripts %}
</body>
</html>

