from setuptools import setup, find_packages

setup(
    name="dj-palette",
    version="1.0.1.0",
    description="A Django admin system with tools for building custom admin interfaces and reusable components",
    long_description=open("README.md", encoding="utf-8").read(),
    long_description_content_type="text/markdown",
    author="Joel O. Tanko",
    author_email="7thogofe@gmail.com",
    url="https://github.com/ogofe/dj_palette",
    project_urls={
        "Documentation": "https://django-palette.readthedocs.io",
        "Issues": "https://github.com/ogofe/dj_palette/issues",
        "Repository": "https://github.com/ogofe/dj_palette",
    },
    packages=find_packages(include=['dj_palette', 'dj_palette.*']),
    include_package_data=True,
    package_data={
        'dj_palette': [
            'templates/**/*.html',
            'static/**/*',
            'migrations/**/*.py',
            'templatetags/**/*.py',
            'palette_admin/**/*',
            'palette_admin/templates/**/*.html',
            'palette_admin/static/**/*',
            'palette_admin/migrations/**/*.py',
        ],
    },
    install_requires=[
        "Django>=2.2",
    ],
    classifiers=[
        "Framework :: Django",
        "Framework :: Django :: 2.2",
        "Framework :: Django :: 3.0",
        "Framework :: Django :: 3.1",
        "Framework :: Django :: 3.2",
        "Framework :: Django :: 4.0",
        "Framework :: Django :: 4.1",
        "Framework :: Django :: 4.2",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.7",
        "Programming Language :: Python :: 3.8",
        "Programming Language :: Python :: 3.9",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
        "Programming Language :: Python :: 3.13",
        "Operating System :: OS Independent",
        "License :: OSI Approved :: MIT License",
    ],
    python_requires=">=3.7",
)
